@@ -7,5 +7,5 @@ test_that("belplauEval", {
   y <- bca(tt = matrix(c(1,0,0,1,1,1),nrow = 2, byrow = TRUE), m = c(0.6, 0.4), cnames = c("a", "b", "c"),  varnames = "y", idvar = 1)
   xy <- nzdsr(dsrwon(x,y))
   z<-belplau(xy,h=ttmatrixPartition(3,3))
-  expect_equal(belplauEval(z,c(0,1,0)),0.5)
+  expect_equal(belplauEval(z,c(1,0,0)),0)
 })
